@@ -12,4 +12,4 @@ def cli():
 @click.option('-url', type=str, help='Length of password to be generated')
 
 def fungit(url):
-    click.echo(gf.remote(url)
+    click.echo(gf.remote(url))
